OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Todos" : "待办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "{actor} 取消共享 {calendar} 给您",
    "You unshared calendar {calendar} from {user}" : "您取消共享给 {user} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 取消共享给 {uesr} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消共享日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您取消共享给组 {group} 的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 取消共享给组 {group} 的日历 {calendar}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Death of %s" : "%s 的忌日",
    "Contact birthdays" : "联系人生日",
    "Calendar:" : "日历：",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "Untitled event" : "未命名事件",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n minute_::_%n minutes_" : ["%n 分钟"],
    "%s (in %s)" : "%s （在 %s）",
    "%s (%s ago)" : "%s （%s 前）",
    "Calendar: %s" : "日历：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地点：%s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Invitation canceled" : "邀请已取消",
    "Hello %s," : "您好，%s，",
    "The meeting »%1$s« with %2$s was canceled." : "与%2$s的会议 »%1$s« 已取消。",
    "Invitation updated" : "邀请已更新",
    "The meeting »%1$s« with %2$s was updated." : "与%2$s的会议 »%1$s« 已更新。",
    "%1$s invited you to »%2$s«" : "%1$s 邀请您加入 »%2$s«",
    "When:" : "时间：",
    "Link:" : "链接：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "More options at %s" : "在%s的更多选项",
    "Contacts" : "联系人",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的%s 需要配置使用HTTPS以在iOS/macOS中使用CalDAV和CardDAV。",
    "Configures a CalDAV account" : "配置一个 CalDAV 账号",
    "Configures a CardDAV account" : "配置一个 CardDAV 账号",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV端点",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址：%s",
    "Request ID: %s" : "请求 ID：%s",
    "There was an error updating your attendance status." : "更新您的出席状态时出错。",
    "Please contact the organizer directly." : "请直接联系组织者。",
    "Are you accepting the invitation?" : "您是否接受邀请？",
    "Tentative" : "暂定",
    "Save" : "保存",
    "Your attendance was updated successfully." : "您的出席状态更新成功。",
    "Calendar server" : "日历服务器",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装 {calendarappstoreopen}日历应用{linkclose}，或者 {calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
    "Send invitations to attendees" : "向参与者发送邀请",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置 {emailopen}邮件服务器{linkclose}。",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "Send notifications for events" : "发送事件通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
    "Enable notifications for events via push" : "启用推送事件通知",
    "Please make sure to properly set up the email settings above." : "请确保正确设置上面的电子邮件设置。",
    "Notifications will be send through background jobs, so these need to happen often enough." : "通知将通过后台任务发送，所以任务的频率有足够高。"
},
"nplurals=1; plural=0;");
